@@ -31,31 +31,45 @@ class WeakNetworkConfig(object):
         self.device_ip = None
         self.device = None
         self._stf = STFServer(url=stf_url, token=sft_token)
-        self.serail = None
+        self._serial_list = []
+        self._device_list = []
+        self._device_ip_list = []
+        self.platform = None
 
-    def _get_device_info(self, device_serial, platform='ios'):
+    def _get_device_info(self, platform='ios'):
         """
             获取当前设备信息
-            :param device_serial: 设备serial
             :param platform: ios/android
         """
         self.platform = platform
-        if self.device is None:
-            self.device = self._stf.get_device_info(device_serial, platform)
-        if self.device is None:
-            raise Exception('No devices:{} found'.format(device_serial))
+        for serial in self._serial_list:
+            device = self._stf.get_device_info(serial, platform)
+            if device:
+                self._device_list.append(device)
+            else:
+                raise Exception('No devices:{} found'.format(serial))
 
-    def connect_wifi(self, device_serial, platform='ios'):
+    def connect_wifi(self, serial_list, platform='ios'):
         """
             连接弱网WIFI热点
         """
+        self._serial_list = serial_list
         self.platform = platform
-        self.serail = device_serial
         if self.platform == 'ios':
-            self._get_device_info(device_serial, platform=platform)
-            return self._connect_ios()
+            self._get_device_info(platform=platform)
+            for dev in self.device:
+                if self._connect_ios(dev):
+                    continue
+                else:
+                    return False
+            return True
         else:
-            return self._connect_android()
+            for serial in serial_list:
+                if self._connect_android(serial):
+                    continue
+                else:
+                    return False
+            return True
 
     def disconnect_wifi(self):
         """
@@ -66,26 +80,28 @@ class WeakNetworkConfig(object):
         else:
             return self._disconnect_android()
 
-    def _connect_android(self):
-        ret = self._stf.toggleAndroidWifi(self.serail, "1", wifiname=self._wifi_name, wifipass=self._wifi_password)
+    def _connect_android(self, serial):
+        ret = self._stf.toggleAndroidWifi(serial, "1", wifiname=self._wifi_name, wifipass=self._wifi_password)
         ip = ret.get("ip", None)
         if str(ip).startswith("192.168.0"):
+            self._device_ip_list.append(ip)
             return True
         else:
             return False
 
-    def _connect_ios(self):
+    def _connect_ios(self, device):
         # 发送自动点击弹窗配置
-        self._stf.watch_alert(self.device['wda_url'])
-        self._stf.stop_ios_app(self.device['wda_url'], WeakNetworkConfig.IOS_APP_BUNDLE_ID)
-        self._stf.launch_ios_app(self.device['wda_url'], WeakNetworkConfig.IOS_APP_BUNDLE_ID)
+        self._stf.watch_alert(device['wda_url'])
+        self._stf.stop_ios_app(device['wda_url'], WeakNetworkConfig.IOS_APP_BUNDLE_ID)
+        self._stf.launch_ios_app(device['wda_url'], WeakNetworkConfig.IOS_APP_BUNDLE_ID)
         timeout = 5 * 60
         t1 = time.time()
         while True:
             if time.time() - t1 > timeout:
-                raise Exception('get_device_ip:{} timeout:{}'.format(self.device['wda_url'], timeout))
-            self._device_ip = self._stf.get_device_ip(self.device['wda_url'], self.platform)
+                raise Exception('get_device_ip:{} timeout:{}'.format(device['wda_url'], timeout))
+            self._device_ip = self._stf.get_device_ip(device['wda_url'], self.platform)
             if self._device_ip:
+                self._device_ip_list.append(self._device_ip)
                 # 弱网断网现在是192.168.0 如果网段变化则需要修改下面的逻辑
                 if self._device_ip.startswith('192.168.0'):
                     self._set_auth()
@@ -94,23 +110,22 @@ class WeakNetworkConfig(object):
                     return False
 
     def _disconnect_android(self):
-        if self.serail:
-            ret = self._stf.toggleAndroidWifi(self.serail, "3", self._wifi_name, self._wifi_password)
+        for serial in self._serial_list:
+            ret = self._stf.toggleAndroidWifi(serial, "3", self._wifi_name, self._wifi_password)
             ip = ret.get("ip", None)
             if not str(ip).startswith("192.168.0"):
-                return True
+                continue
             else:
                 return False
-        else:
-            raise Exception(f"device_serial is None")
+        return True
 
     def _disconnect_ios(self):
-        self.bundle_id = self._stf.find_ios_bundle_id(self.serail, WeakNetworkConfig.IOS_APP_BUNDLE_ID)
-        if self.bundle_id is None:
-            raise Exception('No iOS app bundle:{} found'.format(WeakNetworkConfig.IOS_APP_BUNDLE_ID))
-        self._stf.stop_ios_app(self.device['wda_url'], WeakNetworkConfig.IOS_APP_BUNDLE_ID)
-        self._stf.launch_ios_app(self.device['wda_url'], WeakNetworkConfig.IOS_APP_BUNDLE_ID, args=['disconnect'])
-        return True
+        for dev in self._device_list:
+            self.bundle_id = self._stf.find_ios_bundle_id(dev['serial'], WeakNetworkConfig.IOS_APP_BUNDLE_ID)
+            if self.bundle_id is None:
+                raise Exception('No iOS app bundle:{} found'.format(WeakNetworkConfig.IOS_APP_BUNDLE_ID))
+            self._stf.stop_ios_app(self.device['wda_url'], WeakNetworkConfig.IOS_APP_BUNDLE_ID)
+            self._stf.launch_ios_app(self.device['wda_url'], WeakNetworkConfig.IOS_APP_BUNDLE_ID, args=['disconnect'])
 
     def _set_auth(self):
         url = "{host}{uri}".format(host=self._atc_host,
@@ -129,16 +144,18 @@ class WeakNetworkConfig(object):
         :param config_json: 弱网配置参数
         :return: True if successful
         """
-        url = "{host}{uri}".format(host=self._atc_host,
-                                   uri=WeakNetworkConfig.ATC_SHAPE_URI.format(self._device_ip))
-        r = requests.post(url, json=config_json)
-        try:
-            if r.status_code == 200:
-                return True
-            else:
+        for device_ip in self._device_ip_list:
+            url = "{host}{uri}".format(host=self._atc_host,
+                                       uri=WeakNetworkConfig.ATC_SHAPE_URI.format(device_ip))
+            r = requests.post(url, json=config_json)
+            try:
+                if r.status_code == 200:
+                    continue
+                else:
+                    return False
+            except Exception as e:
                 return False
-        except Exception as e:
-            return False
+        return True
 
 
 if __name__ == '__main__':
